==> zio-aws-pinpoint_3-5.17.104.12-sources.jar: zio/aws/pinpoint/model/GetSegmentVersionRequest.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.pinpoint.model.primitives.__string
import scala.jdk.CollectionConverters.*
final case class GetSegmentVersionRequest(
    applicationId: __string,
    segmentId: __string,
    version: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.GetSegmentVersionRequest = {
    import GetSegmentVersionRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.GetSegmentVersionRequest
      .builder()
      .applicationId(__string.unwrap(applicationId): java.lang.String)
      .segmentId(__string.unwrap(segmentId): java.lang.String)
      .version(__string.unwrap(version): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.pinpoint.model.GetSegmentVersionRequest.ReadOnly =
    zio.aws.pinpoint.model.GetSegmentVersionRequest.wrap(buildAwsValue())
}
object GetSegmentVersionRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.GetSegmentVersionRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.GetSegmentVersionRequest =
      zio.aws.pinpoint.model
        .GetSegmentVersionRequest(applicationId, segmentId, version)
    def applicationId: __string
    def segmentId: __string
    def version: __string
    def getApplicationId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(applicationId)
    def getSegmentId: ZIO[Any, Nothing, __string] = ZIO.succeed(segmentId)
    def getVersion: ZIO[Any, Nothing, __string] = ZIO.succeed(version)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.GetSegmentVersionRequest
  ) extends zio.aws.pinpoint.model.GetSegmentVersionRequest.ReadOnly {
    override val applicationId: __string =
      zio.aws.pinpoint.model.primitives.__string(impl.applicationId())
    override val segmentId: __string =
      zio.aws.pinpoint.model.primitives.__string(impl.segmentId())
    override val version: __string =
      zio.aws.pinpoint.model.primitives.__string(impl.version())
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.GetSegmentVersionRequest
  ): zio.aws.pinpoint.model.GetSegmentVersionRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-pinpoint_3-6.20.78.3-sources.jar: zio/aws/pinpoint/model/GetSegmentVersionRequest.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.pinpoint.model.primitives.__string
import scala.jdk.CollectionConverters.*
final case class GetSegmentVersionRequest(
    applicationId: __string,
    segmentId: __string,
    version: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.GetSegmentVersionRequest = {
    import GetSegmentVersionRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.GetSegmentVersionRequest
      .builder()
      .applicationId(applicationId: java.lang.String)
      .segmentId(segmentId: java.lang.String)
      .version(version: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.pinpoint.model.GetSegmentVersionRequest.ReadOnly =
    zio.aws.pinpoint.model.GetSegmentVersionRequest.wrap(buildAwsValue())
}
object GetSegmentVersionRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.GetSegmentVersionRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.GetSegmentVersionRequest =
      zio.aws.pinpoint.model
        .GetSegmentVersionRequest(applicationId, segmentId, version)
    def applicationId: __string
    def segmentId: __string
    def version: __string
    def getApplicationId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(applicationId)
    def getSegmentId: ZIO[Any, Nothing, __string] = ZIO.succeed(segmentId)
    def getVersion: ZIO[Any, Nothing, __string] = ZIO.succeed(version)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.GetSegmentVersionRequest
  ) extends zio.aws.pinpoint.model.GetSegmentVersionRequest.ReadOnly {
    override val applicationId: __string = impl.applicationId(): __string
    override val segmentId: __string = impl.segmentId(): __string
    override val version: __string = impl.version(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.GetSegmentVersionRequest
  ): zio.aws.pinpoint.model.GetSegmentVersionRequest.ReadOnly = new Wrapper(
    impl
  )
}
